"""Auto-generated file, do not edit by hand. TA metadata"""
from ..phonemetadata import NumberFormat, PhoneNumberDesc, PhoneMetadata

PHONE_METADATA_TA = PhoneMetadata(id='TA', country_code=290, international_prefix='00',
    general_desc=PhoneNumberDesc(national_number_pattern='8\\d{3}', possible_length=(4,)),
    fixed_line=PhoneNumberDesc(national_number_pattern='8\\d{3}', example_number='8999', possible_length=(4,)),
    leading_digits='8')
